==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/appplatform/kotlin/inputs/ApiPortalCustomDomainPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.appplatform.kotlin.inputs

import com.pulumi.azurenative.appplatform.inputs.ApiPortalCustomDomainPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The properties of custom domain for API portal
 * @property thumbprint The thumbprint of bound certificate.
 */
public data class ApiPortalCustomDomainPropertiesArgs(
    public val thumbprint: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.appplatform.inputs.ApiPortalCustomDomainPropertiesArgs> {
    override fun toJava():
        com.pulumi.azurenative.appplatform.inputs.ApiPortalCustomDomainPropertiesArgs =
        com.pulumi.azurenative.appplatform.inputs.ApiPortalCustomDomainPropertiesArgs.builder()
            .thumbprint(thumbprint?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ApiPortalCustomDomainPropertiesArgs].
 */
@PulumiTagMarker
public class ApiPortalCustomDomainPropertiesArgsBuilder internal constructor() {
    private var thumbprint: Output<String>? = null

    /**
     * @param value The thumbprint of bound certificate.
     */
    @JvmName("ydwkgdolibxmscym")
    public suspend fun thumbprint(`value`: Output<String>) {
        this.thumbprint = value
    }

    /**
     * @param value The thumbprint of bound certificate.
     */
    @JvmName("ppgtbodulklpfjtl")
    public suspend fun thumbprint(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.thumbprint = mapped
    }

    internal fun build(): ApiPortalCustomDomainPropertiesArgs = ApiPortalCustomDomainPropertiesArgs(
        thumbprint = thumbprint,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/appplatform/kotlin/inputs/ApiPortalCustomDomainPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.appplatform.kotlin.inputs

import com.pulumi.azurenative.appplatform.inputs.ApiPortalCustomDomainPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The properties of custom domain for API portal
 * @property thumbprint The thumbprint of bound certificate.
 */
public data class ApiPortalCustomDomainPropertiesArgs(
    public val thumbprint: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.appplatform.inputs.ApiPortalCustomDomainPropertiesArgs> {
    override fun toJava():
        com.pulumi.azurenative.appplatform.inputs.ApiPortalCustomDomainPropertiesArgs =
        com.pulumi.azurenative.appplatform.inputs.ApiPortalCustomDomainPropertiesArgs.builder()
            .thumbprint(thumbprint?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ApiPortalCustomDomainPropertiesArgs].
 */
@PulumiTagMarker
public class ApiPortalCustomDomainPropertiesArgsBuilder internal constructor() {
    private var thumbprint: Output<String>? = null

    /**
     * @param value The thumbprint of bound certificate.
     */
    @JvmName("psmauujuajamqskt")
    public suspend fun thumbprint(`value`: Output<String>) {
        this.thumbprint = value
    }

    /**
     * @param value The thumbprint of bound certificate.
     */
    @JvmName("prymjxiupuvmgmhd")
    public suspend fun thumbprint(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.thumbprint = mapped
    }

    internal fun build(): ApiPortalCustomDomainPropertiesArgs = ApiPortalCustomDomainPropertiesArgs(
        thumbprint = thumbprint,
    )
}
